Crate kcode_k1_access_profile_codec

Crate kcode_k1_access_profile_codec 

Canonical version 1 binary encoding for K1 authorization profiles.

This crate is a stateless value codec. See Documentation.md for the byte layout and a usage example.

Structs

AuthorizationProfile
GroupId
ModelId
TxId
UserId

Enums

ProfileOwner
ProfileViewer

Functions

decode_profile
Decodes a complete canonical version 1 authorization profile.
encode_profile
Encodes an authorization profile in the canonical version 1 format.